@@ -8,6 +8,6 @@ includedir="${prefix}/include"
 
 XMLSEC_LIBDIR="${exec_prefix}/lib"
 XMLSEC_INCLUDEDIR=" -D__XMLSEC_FUNCTION__=__func__ -DXMLSEC_NO_GOST=1 -DXMLSEC_NO_GOST2012=1 -DXMLSEC_DL_LIBLTDL=1 -I${prefix}/include/xmlsec1   -I/usr/local/include/libxml2 -I/usr/local/include -I/usr/local/include -I/usr/local/include/libxml2  -DXMLSEC_CRYPTO_OPENSSL=1"
-XMLSEC_LIBS="-L${exec_prefix}/lib -lxmlsec1-openssl -lxmlsec1 -lltdl  -L/usr/local/lib -lxml2 -L/usr/local/lib -lxslt -lm -lxml2  -lssl -lcrypto"
-MODULE_VERSION="xmlsec-1.2.26-openssl"
+XMLSEC_LIBS="-L${exec_prefix}/lib -lxmlsec1-openssl -lxmlsec1 -lltdl  -L/usr/local/lib -lxml2 -L/usr/local/lib -lxslt -lxml2  -lssl -lcrypto"
+MODULE_VERSION="xmlsec-1.2.34-openssl"
 
